| .qgcomp_object_add | R Documentation |
qgcompfit object.qgcomp_object_add developer function to add items to an existing qgcompfit object
.qgcomp_object_add(x, ..., overwrite_duplicates = TRUE)
x |
|
... |
named objects to add to the |
overwrite_duplicates |
(logical) overwrite list items in |
This is not a generally useful function, except for developers, who need to add items to an existing qgcompfit object.
a qgcompfit object
set.seed(50)
# linear model, adding an arbitrary string to the object
dat <- data.frame(y=runif(50,-1,1), x1=runif(50), x2=runif(50), z=runif(50))
ft = qgcomp.glm.noboot(f=y ~ z + x1 + x2, expnms = c('x1', 'x2'), data=dat, q=2, family=gaussian())
ft2 = .qgcomp_object_add(ft, date=Sys.Date())
ft2$date # not typically part of a qgcomp object, but could be useful for e.g. datestamping analyses
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.